Module optimize_props_method_calls

Module optimize_props_method_calls 

Converts MethodCall instructions on props objects into CallExpression instructions.

When the receiver of a method call is typed as the component’s props object, we can safely convert the method call props.foo(args) into a direct call foo(args) using the property as the callee. This simplifies downstream analysis by removing the receiver dependency.

Analogous to TS Optimization/OptimizePropsMethodCalls.ts.

Functions

optimize_props_method_calls